#
# spec file for package ghc-persistent-template
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name persistent-template
Name:           ghc-%{pkg_name}
Version:        2.12.0.0
Release:        bp155.2.14
Summary:        Type-safe, non-relational, multi-backend persistence
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}

%description
Hackage documentation generation is not reliable. For up to date documentation,
please see: <http://www.stackage.org/package/persistent-template>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build_without_haddock

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Wed Mar 31 2021 psimons@suse.com
- Update persistent-template to version 2.12.0.0.
  [#]# 2.12.0.0
  * Decomposed `HaskellName` into `ConstraintNameHS`, `EntityNameHS`, `FieldNameHS`. Decomposed `DBName` into `ConstraintNameDB`, `EntityNameDB`, `FieldNameDB` respectively. [#1174](https://github.com/yesodweb/persistent/pull/1174)
  * [#1214](https://github.com/yesodweb/persistent/pull/1214):
  * This package was asborbed into `persistent` itself.
* Tue Mar 23 2021 psimons@suse.com
- Update persistent-template to version 2.9.1.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sat Nov  7 2020 psimons@suse.com
- Update persistent-template to version 2.9.1.0.
  [#]# 2.9.1.0
  * [#1145](https://github.com/yesodweb/persistent/pull/1148)
  * Fix a bug where the `SqlType` for a shared primary key was being
    incorrectly set to `SqlString` instead of whatever the target primary key
    sql type was.
  * [#1151](https://github.com/yesodweb/persistent/pull/1151)
  * Automatically generate `SymbolToField` instances for datatypes, allowing
    `OverloadedLabels` to be used with the `EntityField` type.
  [#]# 2.9
  * Always use the "stock" strategy when deriving Show/Read for keys [#1106](https://github.com/yesodweb/persistent/pull/1106)
  * This fixes a regression from 2.8.0, which started using the `newtype` strategy when deriving `Show`/`Read` for keys
  * In practice, this means that from 2.8.0–2.8.3.1, for the following schema:
  ```
  Person
  name Text
  CustomPrimary
  anInt Int
  Primary anInt
  name Text
  ```
  `PersonKey 1` would show as `"SqlBackendKey {unSqlBackendKey = 1}"`
  and `CustomPrimaryKey 1` would show as `"1"`
  This was generally poor for debugging and logging, since all tables keys would print the same. For Persistent < 2.8.0 and > 2.8.3.1, they instead will show as:
  `"PersonKey {unPersonKey = SqlBackendKey {unSqlBackendKey = 1}}"`
  and `"CustomPrimaryKey {unCustomPrimaryKey = 1}"`
  This could be a breaking change if you have used `Show` on a key, wrote that string into some persistent storage like a database, and are trying to `Read` it back again later.
  [#]# 2.8.3.1
  * Allow aeson 1.5. [#1085](https://github.com/yesodweb/persistent/pull/1085)
  [#]# 2.8.3.0
  * Add `Lift` instances for the cascade types. [#1060](https://github.com/yesodweb/persistent/pull/1060)
  * Use `DeriveLift` to implement all `Lift` instances. Among other benefits,
    this provides implementations of `liftTyped` on `template-haskell-2.16` (GHC
    8.10) or later. [#1064](https://github.com/yesodweb/persistent/pull/1064)
* Sat Nov  7 2020 psimons@suse.com
- Update persistent-template to version 2.8.2.3 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Sep 12 2020 psimons@suse.com
- Update persistent-template to version 2.8.2.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Aug 19 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with 6GB min disk space for ppc64/ppc64le
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add persistent-template at version 2.8.2.3.
